@@ -29,21 +29,13 @@ type RepositoryWithDetails struct {
 }
 
 // FindAllForks lists all the forks for the current user.
-func FindAllForks(
-	ctx context.Context,
-	client *github.Client,
-	login string,
-) ([]*RepositoryWithDetails, error) {
+func FindAllForks(ctx context.Context, client *github.Client, login string, skipUpstream bool) ([]*RepositoryWithDetails, error) {
 	var forks []*RepositoryWithDetails
 	repos, err := getAllRepos(ctx, client, login)
 	if err != nil {
 		return forks, nil
 	}
 	for _, r := range repos {
-		if !r.GetFork() {
-			continue
-		}
-
 		login := r.GetOwner().GetLogin()
 		name := r.GetName()
 
@@ -63,6 +55,11 @@ func FindAllForks(
 			return forks, fmt.Errorf("failed to get repository: %s: %w", repo.GetFullName(), err)
 		}
 
+		if skipUpstream {
+			forks = append(forks, buildDetails(repo, nil, nil, resp.StatusCode))
+			continue
+		}
+
 		parent := repo.GetParent()
 
 		// get parent's Issues
@@ -83,9 +80,10 @@ func FindAllForks(
 		if err != nil && resp.StatusCode != 404 {
 			return forks, fmt.Errorf("failed to compare repository with parent: %s: %w", repo.GetFullName(), err)
 		}
-
 		forks = append(forks, buildDetails(repo, issues, commits, resp.StatusCode))
+
 	}
+
 	return forks, nil
 }
 
@@ -99,6 +97,7 @@ func buildDetails(repo *github.Repository, issues []*github.Issue, commits *gith
 	if commits != nil {
 		aheadBy = commits.GetAheadBy()
 	}
+
 	return &RepositoryWithDetails{
 		Name:               repo.GetFullName(),
 		ParentName:         repo.GetParent().GetFullName(),
@@ -120,21 +119,27 @@ func getAllRepos(
 	login string,
 ) ([]*github.Repository, error) {
 	var allRepos []*github.Repository
-	opts := &github.RepositoryListOptions{
-		ListOptions: github.ListOptions{PerPage: pageSize},
-		Affiliation: "owner",
+
+	opts := &github.SearchOptions{
+		Sort:      "created",
+		Order:     "asc",
+		TextMatch: false,
+		ListOptions: github.ListOptions{
+			PerPage: pageSize,
+		},
 	}
 	for {
-		repos, resp, err := client.Repositories.List(ctx, login, opts)
+		repos, resp, err := client.Search.Repositories(ctx, "owner:"+login+" fork:only", opts)
 		if err != nil {
 			return allRepos, err
 		}
-		allRepos = append(allRepos, repos...)
+		allRepos = append(allRepos, repos.Repositories...)
 		if resp.NextPage == 0 {
 			break
 		}
 		opts.ListOptions.Page = resp.NextPage
 	}
+
 	return allRepos, nil
 }
 
